@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 
@@ -46,6 +46,7 @@
 
 void(*_AbortHandler)(const char *error, va_list ap) = NULL;
 void(*_ErrorHandler)(const char *error, va_list ap) = NULL;
+void(*_DebugHandler)(const char *info, va_list ap) = NULL;
 
 
 /* ---------------------------------------------------------------- Public */
@@ -65,3 +66,8 @@ void Bootstrap_setAbortHandler(void(*abortHandler)(const char *error, va_list ap
 void Bootstrap_setErrorHandler(void(*errorHandler)(const char *error, va_list ap)) {
         _ErrorHandler = errorHandler;
 }
+
+
+void Bootstrap_setDebugHandler(void(*debugHandler)(const char *info, va_list ap)) {
+        _DebugHandler = debugHandler;
+}
