@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 
@@ -56,25 +56,26 @@
 
 extern void(*_AbortHandler)(const char *error, va_list ap);
 extern void(*_ErrorHandler)(const char *error, va_list ap);
+extern void(*_DebugHandler)(const char *info, va_list ap);
 
 
 /* ---------------------------------------------------------------- Public */
 
 
-const char *System_getLastError(void) { 
-        return strerror(errno); 
+const char *System_lastError(void) {
+        return strerror(errno);
 }
 
 
-const char *System_getError(int error) { 
-        return strerror(error); 
+const char *System_getError(int error) {
+        return strerror(error);
 }
 
 
 void System_abort(const char *e, ...) {
         va_list ap;
         va_start(ap, e);
-        if (_AbortHandler) 
+        if (_AbortHandler)
                 _AbortHandler(e, ap);
         else {
                 vfprintf(stderr, e, ap);
@@ -87,21 +88,34 @@ void System_abort(const char *e, ...) {
 void System_error(const char *e, ...) {
         va_list ap;
         va_start(ap, e);
-        if (_ErrorHandler) 
+        if (_ErrorHandler)
                 _ErrorHandler(e, ap);
-        else 
+        else
                 vfprintf(stderr, e, ap);
         va_end(ap);
 }
 
 
-int System_getDescriptorsGuarded() {
-        int max = 2<<15;
+void System_debug(const char *d, ...) {
+        if (_DebugHandler) {
+                va_list ap;
+                va_start(ap, d);
+                _DebugHandler(d, ap);
+                va_end(ap);
+        }
+}
+
+
+int System_descriptors(int guard) {
         int fileDescriptors = (int)sysconf(_SC_OPEN_MAX);
         if (fileDescriptors < 2)
                 fileDescriptors = getdtablesize();
         assert(fileDescriptors > 2);
-        return (fileDescriptors > max) ? max : fileDescriptors;
+        if (guard > 0) {
+                if (fileDescriptors > guard)
+                        fileDescriptors = guard;
+        }
+        return fileDescriptors;
 }
 
 
@@ -112,7 +126,7 @@ bool System_random(void *buf, size_t nbytes) {
 #elif defined HAVE_GETRANDOM
         return (getrandom(buf, nbytes, 0) == (ssize_t)nbytes);
 #else
-        int fd = open("/dev/urandom", O_RDONLY);
+        int fd = File_open("/dev/urandom", "r");
         if (fd >= 0) {
                 ssize_t bytes = read(fd, buf, nbytes);
                 close(fd);
@@ -130,7 +144,7 @@ bool System_random(void *buf, size_t nbytes) {
 }
 
 
-unsigned long long System_randomNumber() {
+unsigned long long System_randomNumber(void) {
         unsigned long long random;
         System_random(&random, sizeof(random));
         return random;
