@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 
@@ -40,7 +40,7 @@
  * Returns a String describing the last system error
  * @return The last error message
  */
-const char *System_getLastError(void);
+const char *System_lastError(void);
 
 
 /**
@@ -52,8 +52,8 @@ const char *System_getError(int error);
 
 
 /**
- * Prints the given error message to <code>stderr</code> and 
- * <code>abort(3)</code> the application. If an AbortHandler callback 
+ * Prints the given error message to <code>stderr</code> and
+ * <code>abort(3)</code> the application. If an AbortHandler callback
  * function is defined for the library, this function is called instead.
  * @param e A formatted (printf-style) message string
  */
@@ -68,13 +68,28 @@ void System_abort(const char *e, ...) __attribute__((format (printf, 1, 2)));
 void System_error(const char *e, ...) __attribute__((format (printf, 1, 2)));
 
 
+/**
+ * If a DebugHandler function is defined for the library, call this function
+ * with the given debug message. If a DebugHandler function is not defined
+ * this method does nothing.
+ * @param d A formatted (printf-style) debug string
+ */
+void System_debug(const char *d, ...) __attribute__((format (printf, 1, 2)));
+
+
 /**
  * Returns the number of available file descriptors for a process.
- * This method uses <code>sysconf</code> internally, but returns
- * a fixed size of <code>2^16</code> if the value is larger. 
+ * This method uses <code>sysconf</code> internally. If the guard
+ * parameter is 0, return the value from <code>sysconf</code>. If
+ * the guard parameter is > 0 and available descriptors is larger
+ * than guard, return the guard value instead.
+ * @param guard If guard is > 0 and available descriptors is larger
+ * than guard, return the guard value instead. Otherwise if guard
+ * is 0, return the maximum available file descriptors for a process
+ * as reported by the system
  * @return A guarded number of available file descriptors for a process
  */
-int System_getDescriptorsGuarded(void);
+int System_descriptors(int guard);
 
 
 /**
