@@ -26,9 +26,9 @@
 #define MONIT_DEVICE_H
 
 
-boolean_t filesystem_usage(Service_T);
-boolean_t Filesystem_getByMountpoint(Info_T inf, const char *path);
-boolean_t Filesystem_getByDevice(Info_T inf, const char *path);
+bool filesystem_usage(Service_T);
+bool Filesystem_getByMountpoint(Info_T inf, const char *path);
+bool Filesystem_getByDevice(Info_T inf, const char *path);
 
 
 #endif
