@@ -485,7 +485,6 @@ static bool _setDevice(Info_T inf, const char *path, bool (*compare)(const char
                 FREE(mnt);
         }
         Log_error("Lookup for '%s' filesystem failed\n", path);
-error:
         inf->filesystem->object.mounted = false;
         return false;
 }
@@ -503,15 +502,15 @@ static bool _getDevice(Info_T inf, const char *path, bool (*compare)(const char
 
 
 bool Filesystem_getByMountpoint(Info_T inf, const char *path) {
-        ASSERT(inf);
-        ASSERT(path);
+        assert(inf);
+        assert(path);
         return _getDevice(inf, path, _compareMountpoint);
 }
 
 
 bool Filesystem_getByDevice(Info_T inf, const char *path) {
-        ASSERT(inf);
-        ASSERT(path);
+        assert(inf);
+        assert(path);
         return _getDevice(inf, path, _compareDevice);
 }
 
