@@ -492,8 +492,12 @@ static bool _getDevice(Info_T inf, const char *path, bool (*compare)(const char
                 _statistics.fd = open(MOUNTS, O_RDONLY);
         }
         if (_statistics.fd != -1) {
+                int rv;
                 struct pollfd mountNotify = {.fd = _statistics.fd, .events = POLLPRI, .revents = 0};
-                if (poll(&mountNotify, 1, 0) != -1) {
+                do {
+                        rv = poll(&mountNotify, 1, 0);
+                } while (rv == -1 && errno == EINTR);
+                if (rv != -1) {
                         if (mountNotify.revents & POLLERR) {
                                 DEBUG("Mount table change detected\n");
                                 _statistics.generation++;
