@@ -61,7 +61,6 @@
 #include "alert.h"
 #include "event.h"
 #include "state.h"
-#include "ProcessTree.h"
 #include "MMonit.h"
 
 // libmonit
@@ -138,7 +137,7 @@ static void _saveState(long id, State_Type state) {
  * @return The event state
  */
 static bool _checkState(Event_T E, State_Type S) {
-        ASSERT(E);
+        assert(E);
         int count = 0;
         State_Type state = (S == State_Succeeded || S == State_ChangedNot) ? State_Succeeded : State_Failed; /* translate to 0/1 class */
 
@@ -151,7 +150,7 @@ static bool _checkState(Event_T E, State_Type S) {
         /* Compare as many bits as cycles able to trigger the action */
         for (int i = 0; i < action->cycles; i++) {
                 /* Check the state of the particular cycle given by the bit position */
-                long long flag = (E->state_map >> i) & 0x1;
+                State_Type flag = (E->state_map >> i) & 0x1;
 
                 /* Count occurrences of the posted state */
                 if (flag == state)
@@ -173,8 +172,8 @@ static bool _checkState(Event_T E, State_Type S) {
  * @param E An event object
  */
 static void _queueAdd(Event_T E) {
-        ASSERT(E);
-        ASSERT(E->flag != Handler_Succeeded);
+        assert(E);
+        assert(E->flag != Handler_Succeeded);
 
         if (! file_checkQueueDirectory(Run.eventlist_dir)) {
                 Log_error("Aborting event - cannot access the event queue directory %s\n", Run.eventlist_dir);
@@ -247,8 +246,8 @@ static void _queueUpdate(Event_T E, const char *file_name) {
         Action_Type action = Event_get_action(E);
         bool rv;
 
-        ASSERT(E);
-        ASSERT(E->flag != Handler_Succeeded);
+        assert(E);
+        assert(E->flag != Handler_Succeeded);
 
         if (! file_checkQueueDirectory(Run.eventlist_dir)) {
                 Log_error("Aborting event - cannot access the event queue directory %s\n", Run.eventlist_dir);
@@ -294,8 +293,8 @@ error:
 
 
 static void _handleAction(Event_T E, Action_T A) {
-        ASSERT(E);
-        ASSERT(A);
+        assert(E);
+        assert(A);
 
         E->flag = Handler_Succeeded;
 
@@ -333,10 +332,10 @@ static void _handleAction(Event_T E, Action_T A) {
 
 
 static void _handleEvent(Service_T S, Event_T E) {
-        ASSERT(E);
-        ASSERT(E->action);
-        ASSERT(E->action->failed);
-        ASSERT(E->action->succeeded);
+        assert(E);
+        assert(E->action);
+        assert(E->action->failed);
+        assert(E->action->succeeded);
 
         /* We will handle only first succeeded event, recurrent succeeded events
          * or insufficient succeeded events during failed service state are
@@ -386,6 +385,16 @@ static void _handleEvent(Service_T S, Event_T E) {
 }
 
 
+#if defined(__clang__) && defined(__clang_major__) && __clang_major__ >= 12
+__attribute__((no_sanitize("unsigned-integer-overflow", "unsigned-shift-base")))
+#elif defined(__clang__) && defined(__clang_major__) && __clang_major__ >= 4
+__attribute__((no_sanitize("unsigned-integer-overflow")))
+#endif
+static unsigned long long left_shift(unsigned long long v) {
+        return v << 1;
+}
+
+
 /* ------------------------------------------------------------------ Public */
 
 
@@ -398,10 +407,10 @@ static void _handleEvent(Service_T S, Event_T E) {
  * @param s Optional message describing the event
  */
 void Event_post(Service_T service, long id, State_Type state, EventAction_T action, const char *s, ...) {
-        ASSERT(service);
-        ASSERT(action);
-        ASSERT(s);
-        ASSERT(state == State_Failed || state == State_Succeeded || state == State_Changed || state == State_ChangedNot);
+        assert(service);
+        assert(action);
+        assert(s);
+        assert(state == State_Failed || state == State_Succeeded || state == State_Changed || state == State_ChangedNot);
 
         _saveState(id, state);
 
@@ -416,7 +425,7 @@ void Event_post(Service_T service, long id, State_Type state, EventAction_T acti
                         gettimeofday(&e->collected, NULL);
 
                         /* Shift the existing event flags to the left and set the first bit based on actual state */
-                        e->state_map <<= 1;
+                        e->state_map = left_shift(e->state_map);
                         e->state_map |= ((state == State_Succeeded || state == State_ChangedNot) ? 0 : 1);
 
                         /* Update the message */
@@ -467,7 +476,7 @@ void Event_post(Service_T service, long id, State_Type state, EventAction_T acti
  * event type is not found NULL is returned.
  */
 const char *Event_get_description(Event_T E) {
-        ASSERT(E);
+        assert(E);
         EventTable_T *et = Event_Table;
         while ((*et).id) {
                 if (E->id == (*et).id) {
@@ -498,7 +507,7 @@ const char *Event_get_description(Event_T E) {
  * @return An action id
  */
 Action_Type Event_get_action(Event_T E) {
-        ASSERT(E);
+        assert(E);
         Action_T A = NULL;
         switch (E->state) {
                 case State_Succeeded:
@@ -532,15 +541,15 @@ Action_Type Event_get_action(Event_T E) {
  * event type is not found NULL is returned.
  */
 const char *Event_get_action_description(Event_T E) {
-        ASSERT(E);
-        return actionnames[Event_get_action(E)];
+        assert(E);
+        return Action_Names[Event_get_action(E)];
 }
 
 
 /**
  * Reprocess the partially handled event queue
  */
-void Event_queue_process() {
+void Event_queue_process(void) {
         /* return in the case that the eventqueue is not enabled or empty */
         if (! Run.eventlist_dir || (! (Run.flags & Run_HandlerInit) && ! Run.handler_queue[Handler_Alert] && ! Run.handler_queue[Handler_Mmonit]))
                 return;
