@@ -167,11 +167,11 @@ void add_Impl(void(*doGet)(HttpRequest, HttpResponse), void(*doPost)(HttpRequest
 }
 
 
-void Processor_setHttpPostLimit() {
+void Processor_setHttpPostLimit(void) {
         // Base buffer size (space for e.g. "action=<name>")
         _httpPostLimit = STRLEN;
         // Add space for each service
-        for (Service_T s = servicelist; s; s = s->next)
+        for (Service_T s = Service_List; s; s = s->next)
                 _httpPostLimit += strlen("&service=") + strlen(s->name);
 }
 
@@ -198,7 +198,7 @@ StringBuffer_T escapeHTML(StringBuffer_T sb, const char *s) {
  * @param msg Optional error message (may be NULL)
  */
 void send_error(HttpRequest req, HttpResponse res, int code, const char *msg, ...) {
-        ASSERT(msg);
+        assert(msg);
 
         const char *err = get_status_string(code);
         reset_response(res);
@@ -245,8 +245,8 @@ void send_error(HttpRequest req, HttpResponse res, int code, const char *msg, ..
 void set_header(HttpResponse res, const char *name, const char *value, ...) {
         HttpHeader h = NULL;
 
-        ASSERT(res);
-        ASSERT(name);
+        assert(res);
+        assert(name);
 
         NEW(h);
         h->name = Str_dup(name);
@@ -289,7 +289,7 @@ void set_status(HttpResponse res, int code) {
  * @param mime Mime content type, e.g. text/html
  */
 void set_content_type(HttpResponse res, const char *mime) {
-        ASSERT(mime);
+        assert(mime);
         set_header(res, "Content-Type", "%s", mime);
 }
 
@@ -445,7 +445,7 @@ static void do_service(Socket_T s) {
         volatile HttpRequest req = create_HttpRequest(s);
         if (res && req) {
                 if (Run.httpd.socket.net.ssl.flags & SSL_Enabled)
-                        set_header(res, "Strict-Transport-Security", "max-age=63072000; includeSubdomains; preload");
+                        set_header(res, "Strict-Transport-Security", "max-age=63072000");
                 if (is_authenticated(req, res)) {
                         set_header(res, "Set-Cookie", "securitytoken=%s; Max-Age=600; HttpOnly; SameSite=strict%s", res->token, (Run.httpd.socket.net.ssl.flags & SSL_Enabled) ? "; Secure" : "");
                         if (IS(req->method, METHOD_GET))
@@ -517,8 +517,12 @@ static void send_response(HttpRequest req, HttpResponse res) {
                 Socket_print(S, "Server: %s\r\n", server);
                 Socket_print(S, "Content-Length: %zu\r\n", bodyLength);
                 Socket_print(S, "Connection: close\r\n");
+                Socket_print(S, "X-Content-Type-Options: nosniff\r\n");
                 Socket_print(S, "X-Frame-Options: SAMEORIGIN\r\n");
                 Socket_print(S, "Content-Security-Policy: frame-ancestors 'self'\r\n");
+                Socket_print(S, "X-XSS-Protection: 1; mode=block\r\n");
+                Socket_print(S, "Referrer-Policy: same-origin\r\n");
+                Socket_print(S, "Permissions-Policy: geolocation=(),camera=(),microphone=()\r\n");
                 if (headers)
                         Socket_print(S, "%s", headers);
                 Socket_print(S, "\r\n");
@@ -793,7 +797,7 @@ static bool is_authenticated(HttpRequest req, HttpResponse res) {
                                                 break;
                                         }
                                 }
-                                if (Str_compareConstantTime(cookieValue, token)) {
+                                if (! Str_authcmp(cookieValue, token)) {
                                         Log_error("HttpRequest: access denied -- client [%s]: CSRF token mismatch\n", NVLSTR(Socket_getRemoteHost(req->S)));
                                         send_error(req, res, SC_FORBIDDEN, "Invalid CSRF Token");
                                         return false;
@@ -872,8 +876,12 @@ static void internal_error(Socket_T S, int status, const char *msg) {
                      "Server: %s\r\n"
                      "Content-Type: text/html\r\n"
                      "Connection: close\r\n"
+                     "X-Content-Type-Options: nosniff\r\n"
                      "X-Frame-Options: SAMEORIGIN\r\n"
                      "Content-Security-Policy: frame-ancestors 'self'\r\n"
+                     "X-XSS-Protection: 1; mode=block\r\n"
+                     "Referrer-Policy: same-origin\r\n"
+                     "Permissions-Policy: geolocation=(),camera=(),microphone=()\r\n"
                      "\r\n"
                      "<html><head><title>%s</title></head>"
                      "<body bgcolor=#FFFFFF><h2>%s</h2>%s<p>"
