@@ -25,13 +25,13 @@
 #ifndef MONIT_PROCESS_SYSDEP_H
 #define MONIT_PROCESS_SYSDEP_H
 
-bool init_process_info_sysdep(void);
+bool init_systeminfo_sysdep(void);
 int  init_proc_info_sysdep(void);
 int  getloadavg_sysdep (double *, int);
 bool used_system_memory_sysdep(SystemInfo_T *);
 bool used_system_cpu_sysdep(SystemInfo_T *);
 bool used_system_filedescriptors_sysdep(SystemInfo_T *);
 bool available_statistics(SystemInfo_T *);
-int  initprocesstree_sysdep(ProcessTree_T **, ProcessEngine_Flags);
+int init_processtree_sysdep(ProcessTree_T **, ProcessEngine_Flags);
 
 #endif
