@@ -49,6 +49,10 @@
 #include <libproc.h>
 #endif
 
+#ifdef HAVE_COREFOUNDATION_COREFOUNDATION_H
+#include <CoreFoundation/CoreFoundation.h>
+#endif
+
 #include "monit.h"
 #include "ProcessTree.h"
 #include "process_sysdep.h"
@@ -77,43 +81,68 @@ static long cpu_nice_old = 0;
 static long cpu_syst_old = 0;
 
 
+void static _setOSInfo(void) {
+#ifdef HAVE_COREFOUNDATION_COREFOUNDATION_H
+        CFURLRef url = CFURLCreateWithFileSystemPath(NULL, CFSTR("/System/Library/CoreServices/SystemVersion.plist"), kCFURLPOSIXPathStyle, false);
+        if (url) {
+                CFReadStreamRef stream = CFReadStreamCreateWithFile(NULL, url);
+                if (stream) {
+                        if (CFReadStreamOpen(stream)) {
+                                CFPropertyListRef propertyList = CFPropertyListCreateWithStream(NULL, stream, 0, kCFPropertyListImmutable, NULL, NULL);
+                                if (propertyList) {
+                                        CFStringRef value = CFDictionaryGetValue(propertyList, CFSTR("ProductName"));
+                                        if (value) {
+                                                CFStringGetCString(value, System_Info.uname.sysname, sizeof(System_Info.uname.sysname), CFStringGetSystemEncoding());
+                                        }
+                                        value = CFDictionaryGetValue(propertyList, CFSTR("ProductVersion"));
+                                        if (value) {
+                                                CFStringGetCString(value, System_Info.uname.release, sizeof(System_Info.uname.release), CFStringGetSystemEncoding());
+                                        }
+                                        CFRelease(propertyList);
+                                }
+                                CFReadStreamClose(stream);
+                        }
+                        CFRelease(stream);
+                }
+                CFRelease(url);
+        }
+#endif
+}
+
+
 /* ------------------------------------------------------------------ Public */
 
 
-bool init_process_info_sysdep(void) {
-        size_t size = sizeof(systeminfo.cpu.count);
-        if (sysctlbyname("hw.logicalcpu", &systeminfo.cpu.count, &size, NULL, 0) == -1) {
+bool init_systeminfo_sysdep(void) {
+        _setOSInfo();
+        size_t size = sizeof(System_Info.cpu.count);
+        if (sysctlbyname("hw.logicalcpu", &System_Info.cpu.count, &size, NULL, 0) == -1) {
                 DEBUG("system statistics error -- sysctl hw.logicalcpu failed: %s\n", STRERROR);
                 return false;
         }
-
-        size = sizeof(systeminfo.memory.size);
-        if (sysctlbyname("hw.memsize", &systeminfo.memory.size, &size, NULL, 0) == -1) {
+        size = sizeof(System_Info.memory.size);
+        if (sysctlbyname("hw.memsize", &System_Info.memory.size, &size, NULL, 0) == -1) {
                 DEBUG("system statistics error -- sysctl hw.memsize failed: %s\n", STRERROR);
                 return false;
         }
-
         size = sizeof(pagesize);
         if (sysctlbyname("hw.pagesize", &pagesize, &size, NULL, 0) == -1) {
                 DEBUG("system statistics error -- sysctl hw.pagesize failed: %s\n", STRERROR);
                 return false;
         }
-
-        size = sizeof(systeminfo.argmax);
-        if (sysctlbyname("kern.argmax", &systeminfo.argmax, &size, NULL, 0) == -1) {
+        size = sizeof(System_Info.argmax);
+        if (sysctlbyname("kern.argmax", &System_Info.argmax, &size, NULL, 0) == -1) {
                 DEBUG("system statistics error -- sysctl kern.argmax failed: %s\n", STRERROR);
                 return false;
         }
-
         struct timeval booted;
         size = sizeof(booted);
         if (sysctlbyname("kern.boottime", &booted, &size, NULL, 0) == -1) {
                 DEBUG("system statistics error -- sysctl kern.boottime failed: %s\n", STRERROR);
                 return false;
         } else {
-                systeminfo.booted = booted.tv_sec;
+                System_Info.booted = booted.tv_sec;
         }
-
         return true;
 }
 
@@ -124,7 +153,7 @@ bool init_process_info_sysdep(void) {
  * @param pflags Process engine flags
  * @return treesize > 0 if succeeded otherwise 0
  */
-int initprocesstree_sysdep(ProcessTree_T **reference, ProcessEngine_Flags pflags) {
+int init_processtree_sysdep(ProcessTree_T **reference, ProcessEngine_Flags pflags) {
         size_t pinfo_size = 0;
         int mib[] = {CTL_KERN, KERN_PROC, KERN_PROC_ALL, 0};
         if (sysctl(mib, 4, NULL, &pinfo_size, NULL, 0) < 0) {
@@ -139,15 +168,14 @@ int initprocesstree_sysdep(ProcessTree_T **reference, ProcessEngine_Flags pflags
         }
         size_t treesize = pinfo_size / sizeof(struct kinfo_proc);
         ProcessTree_T *pt = CALLOC(sizeof(ProcessTree_T), treesize);
-
         char *args = NULL;
         StringBuffer_T cmdline = NULL;
         if (pflags & ProcessEngine_CollectCommandLine) {
                 cmdline = StringBuffer_create(64);
-                args = CALLOC(1, systeminfo.argmax + 1);
+                args = CALLOC(1, System_Info.argmax + 1);
         }
         for (size_t i = 0; i < treesize; i++) {
-                pt[i].uptime    = systeminfo.time / 10. - pinfo[i].kp_proc.p_starttime.tv_sec;
+                pt[i].uptime    = System_Info.time / 10. - pinfo[i].kp_proc.p_starttime.tv_sec;
                 pt[i].zombie    = pinfo[i].kp_proc.p_stat == SZOMB ? true : false;
                 pt[i].pid       = pinfo[i].kp_proc.p_pid;
                 pt[i].ppid      = pinfo[i].kp_eproc.e_ppid;
@@ -155,7 +183,7 @@ int initprocesstree_sysdep(ProcessTree_T **reference, ProcessEngine_Flags pflags
                 pt[i].cred.euid = pinfo[i].kp_eproc.e_ucred.cr_uid;
                 pt[i].cred.gid  = pinfo[i].kp_eproc.e_pcred.p_rgid;
                 if (pflags & ProcessEngine_CollectCommandLine) {
-                        size_t size = systeminfo.argmax;
+                        size_t size = System_Info.argmax;
                         mib[0] = CTL_KERN;
                         mib[1] = KERN_PROCARGS2;
                         mib[2] = pt[i].pid;
@@ -173,7 +201,7 @@ int initprocesstree_sysdep(ProcessTree_T **reference, ProcessEngine_Flags pflags
                                 char *p = args + sizeof(int); // arguments beginning
                                 StringBuffer_clear(cmdline);
                                 p += strlen(p); // skip exename
-                                while (argc && p < args + systeminfo.argmax) {
+                                while (argc > 0 && p < args + System_Info.argmax) {
                                         if (*p == 0) { // skip terminating 0 and variable length 0 padding
                                                 p++;
                                                 continue;
@@ -233,7 +261,7 @@ int initprocesstree_sysdep(ProcessTree_T **reference, ProcessEngine_Flags pflags
         FREE(pinfo);
 
         *reference = pt;
-        
+
         return (int)treesize;
 }
 
