@@ -74,7 +74,6 @@
 #endif
 
 #ifdef HAVE_SYS_SWAP_H
-#define _SYS_VNODE_H
 #include <sys/swap.h>
 #endif
 
@@ -109,10 +108,10 @@ static long   old_total = 0;
 
 #define MAXSTRSIZE 80
 
-bool init_process_info_sysdep(void) {
-        systeminfo.cpu.count = sysconf( _SC_NPROCESSORS_ONLN);
+bool init_systeminfo_sysdep(void) {
+        System_Info.cpu.count = sysconf( _SC_NPROCESSORS_ONLN);
         page_size = getpagesize();
-        systeminfo.memory.size = (unsigned long long)sysconf(_SC_PHYS_PAGES) * (unsigned long long)page_size;
+        System_Info.memory.size = (unsigned long long)sysconf(_SC_PHYS_PAGES) * (unsigned long long)page_size;
         kstat_ctl_t *kctl = kstat_open();
         if (kctl) {
                 kstat_t *kstat = kstat_lookup(kctl, "unix", 0, "system_misc");
@@ -120,7 +119,7 @@ bool init_process_info_sysdep(void) {
                         if (kstat_read(kctl, kstat, 0) != -1) {
                                 kstat_named_t *knamed = kstat_data_lookup(kstat, "boot_time");
                                 if (knamed)
-                                        systeminfo.booted = (unsigned long long)knamed->value.ul;
+                                        System_Info.booted = (unsigned long long)knamed->value.ul;
                         }
                 }
                 kstat_close(kctl);
@@ -139,8 +138,8 @@ double timestruc_to_tseconds(timestruc_t t) {
  * @param pflags Process engine flags
  * @return treesize > 0 if succeeded otherwise 0
  */
-int initprocesstree_sysdep(ProcessTree_T **reference, ProcessEngine_Flags pflags) {
-        ASSERT(reference);
+int init_processtree_sysdep(ProcessTree_T **reference, ProcessEngine_Flags pflags) {
+        assert(reference);
 
         /* Find all processes in the /proc directory */
         glob_t globbuf;
@@ -164,7 +163,7 @@ int initprocesstree_sysdep(ProcessTree_T **reference, ProcessEngine_Flags pflags
                         pt[i].cred.uid     = psinfo->pr_uid;
                         pt[i].cred.euid    = psinfo->pr_euid;
                         pt[i].cred.gid     = psinfo->pr_gid;
-                        pt[i].uptime       = systeminfo.time / 10. - psinfo->pr_start.tv_sec;
+                        pt[i].uptime       = System_Info.time / 10. - psinfo->pr_start.tv_sec;
                         pt[i].zombie       = psinfo->pr_nlwp == 0 ? true : false; // If we don't have any light-weight processes (LWP) then we are definitely a zombie
                         pt[i].memory.usage = (unsigned long long)psinfo->pr_rssize * 1024;
                         if (pflags & ProcessEngine_CollectCommandLine) {
@@ -267,7 +266,7 @@ bool used_system_memory_sysdep(SystemInfo_T *si) {
                                 knamed = kstat_data_lookup(kstat, "size");
                                 arcsize = (unsigned long long)knamed->value.ul;
                         }
-                        si->memory.usage.bytes = systeminfo.memory.size - freemem - arcsize;
+                        si->memory.usage.bytes = System_Info.memory.size - freemem - arcsize;
                 }
         }
         kstat_close(kctl);
@@ -283,8 +282,8 @@ again:
                 si->swap.size = 0ULL;
                 return true;
         }
-        s = (swaptbl_t *)ALLOC(num * sizeof(swapent_t) + sizeof(struct swaptable));
-        strtab = (char *)ALLOC((num + 1) * MAXSTRSIZE);
+        s = (swaptbl_t *)CALLOC(num, sizeof(swapent_t) + sizeof(struct swaptable));
+        strtab = (char *)CALLOC(num + 1, MAXSTRSIZE);
         for (int i = 0; i < (num + 1); i++)
                 s->swt_ent[i].ste_path = strtab + (i * MAXSTRSIZE);
         s->swt_n = num + 1;
@@ -348,8 +347,8 @@ bool used_system_cpu_sysdep(SystemInfo_T *si) {
                 goto error;
         }
 
-        cpu_ks   = (kstat_t **)ALLOC(ncpus * sizeof(kstat_t *));
-        cpu_stat = (cpu_stat_t *)ALLOC(ncpus * sizeof(cpu_stat_t));
+        cpu_ks   = (kstat_t **)CALLOC(ncpus, sizeof(kstat_t *));
+        cpu_stat = (cpu_stat_t *)CALLOC(ncpus, sizeof(cpu_stat_t));
 
         for (kstat = kctl->kc_chain; kstat; kstat = kstat->ks_next) {
                 if (strncmp(kstat->ks_name, "cpu_stat", 8) == 0) {
