@@ -36,7 +36,7 @@
  */
 
 
-int init_process_info_sysdep(void) {
+int init_systeminfo_sysdep(void) {
         return false;
 }
 
@@ -48,7 +48,7 @@ int init_process_info_sysdep(void) {
  * @param pflags Process engine flags
  * @return treesize > 0 if succeeded otherwise 0
  */
-int initprocesstree_sysdep(ProcessTree_T **reference, ProcessEngine_Flags pflags) {
+int init_processtree_sysdep(ProcessTree_T **reference, ProcessEngine_Flags pflags) {
         return 0;
 }
 
