@@ -40,13 +40,43 @@
 #include "util/Str.h"
 
 
+#define MIN(x,y) ((x) < (y) ? (x) : (y))
+
+// Escape zero i.e. '\0' in the buffer with "\0". If there are no '\0' in
+// the buffer it is returned as it is. In the case that the buffer is not
+// large enough for escaping, the data will be truncated. The buffer will
+// always be nul-terminated.
+static char *_escapeZero(char *buf, int bufferLength, int contentLength) {
+        int currentByteIndex = 0;
+        for (int bytesProcessed = 0; bytesProcessed < contentLength && currentByteIndex < bufferLength; bytesProcessed++, currentByteIndex++) {
+                if (buf[currentByteIndex] == '\0') {
+                        // Escape the zero, unless we run out of space in the buffer. We reserve the last byte for trailing nul-terminator, so if there is no space for the
+                        // nul-terminated escape sequence, we won't perform the escaping and this zero will become the string terminator)
+                        if (currentByteIndex + 1 < bufferLength - 1) {
+                                // Shift the remaining content by one to the right, to make space for '\'. If there's no space for all remaining bytes, we'll truncate the data
+                                memmove(buf + currentByteIndex + 1, buf + currentByteIndex, MIN(contentLength - bytesProcessed, bufferLength - currentByteIndex - 1));
+                                // Escape 0 with "\0"
+                                buf[currentByteIndex] = '\\';
+                                buf[currentByteIndex + 1] = '0';
+                                currentByteIndex++;
+                        }
+                }
+        }
+        if (currentByteIndex < bufferLength)
+                buf[currentByteIndex] = 0;
+        else
+                buf[bufferLength - 1] = 0;
+        return buf;
+}
+
+
 /**
  *  Generic service test.
  *
  *  @file
  */
 void check_generic(Socket_T socket) {
-        ASSERT(socket);
+        assert(socket);
 
         Generic_T g = NULL;
         if (Socket_getPort(socket))
@@ -86,7 +116,7 @@ void check_generic(Socket_T socket) {
                         int n = Socket_read(socket, buf + 1, Run.limits.sendExpectBuffer - 1) + 1;
                         buf[n] = 0;
                         if (n > 0)
-                                Str_escapeZero(buf, Run.limits.sendExpectBuffer + 1, n); // We pass the whole buffer length, including the byte reserved for nul-terminator
+                                _escapeZero(buf, Run.limits.sendExpectBuffer + 1, n); // We pass the whole buffer length, including the byte reserved for nul-terminator
                         Socket_setTimeout(socket, timeout); // Reset back original timeout for next send/expect
                         int regex_return = regexec(g->expect, buf, 0, NULL, 0);
                         if (regex_return != 0) {
