@@ -60,10 +60,10 @@
 
 void check_ntp3(Socket_T socket) {
         int  br;
-        char ntpRequest[NTPLEN] = {};
+        unsigned char ntpRequest[NTPLEN] = {};
         char ntpResponse[NTPLEN] = {};
 
-        ASSERT(socket);
+        assert(socket);
 
         /*
          Prepare NTP request. The first octet consists of:
