@@ -43,6 +43,7 @@
 #include "protocol.h"
 
 // libmonit
+#include "system/Random.h"
 #include "exceptions/IOException.h"
 #include "exceptions/ProtocolException.h"
 
@@ -117,16 +118,16 @@ void check_radius(Socket_T socket) {
                 0x00
         };
 
-        ASSERT(socket);
+        assert(socket);
 
         P = Socket_getPort(socket);
-        ASSERT(P);
+        assert(P);
 
         secret = P->parameters.radius.secret ? P->parameters.radius.secret : "testing123";
         secret_len = (int)strlen(secret);
 
         /* get 16 bytes of random data */
-        System_random(request + 4, 16);
+        Random_bytes(request + 4, 16);
 
         /* sign the packet */
         Checksum_hmacMD5(request, sizeof(request), (const unsigned char *)secret, secret_len, request + 22);
