@@ -29,6 +29,10 @@
 #ifdef HAVE_OPENSSL
 
 
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+
 #ifdef HAVE_STDIO_H
 #include <stdio.h>
 #endif
@@ -41,6 +45,10 @@
 #include <sys/types.h>
 #endif
 
+#ifdef HAVE_SYS_STAT_H
+#include <sys/stat.h>
+#endif
+
 #ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
@@ -61,6 +69,10 @@
 #include <unistd.h>
 #endif
 
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+
 #ifdef HAVE_ERRNO_H
 #include <errno.h>
 #endif
@@ -148,9 +160,68 @@ static Mutex_T *instanceMutexTable;
 static int session_id_context = 1;
 
 
+#ifdef HAVE_SSL_CTX_SET_KEYLOG_CALLBACK
+static FILE *keylog = NULL;
+static const char *keylogName = NULL;
+#endif
+
+
 /* ----------------------------------------------------------------- Private */
 
 
+#ifdef HAVE_SSL_CTX_SET_KEYLOG_CALLBACK
+// Close the SSLKEYLOGFILE
+static void _keylogClose(void) {
+        if (keylog) {
+                if (fclose(keylog) != 0)
+                        Log_error("Cannot close the key log file -- %s\n", STRERROR);
+        }
+}
+
+
+// If the SSLKEYLOGFILE environment variable is set, open the keylog file, to be used with Wireshark for TLS debugging
+static bool _keylogOpen(void) {
+        if (keylog) {
+                // Open already
+                return true;
+        }
+
+        if (keylogName) {
+                // Open the file if SSLKEYLOGFILE is set
+                mode_t savemask = umask(0077);
+                keylog = fopen(keylogName, "a");
+                umask(savemask);
+                if (! keylog) {
+                        Log_error("Cannot open the key log file '%s' -- %s\n", keylogName, STRERROR);
+                        return false;
+                }
+
+                atexit(_keylogClose);
+                fprintf(keylog, "# TLS material log file for Monit Wireshark debugging\n");
+                fflush(keylog);
+                return true;
+        }
+        return false;
+}
+
+
+// Keylog callback for OpenSSL
+static void _keylogWrite(const SSL *ssl, const char *line) {
+        if (ssl && keylog && STR_DEF(line)) {
+                fprintf(keylog, "%s\n", line);
+                fflush(keylog);
+        }
+}
+
+
+// Enable the keylog callback
+static void _keylogSet(SSL_CTX *ctx) {
+        if (Run.debug && _keylogOpen())
+                SSL_CTX_set_keylog_callback(ctx, _keylogWrite);
+}
+#endif
+
+
 static Ssl_Version _optionsVersion(int version) {
         return version != -1 ? version : Run.ssl.version != -1 ? Run.ssl.version : SSL_Auto;
 }
@@ -487,7 +558,7 @@ static bool _setClientCertificate(T C, const char *file) {
 /* ------------------------------------------------------------------ Public */
 
 
-void Ssl_start() {
+void Ssl_start(void) {
 #if (OPENSSL_VERSION_NUMBER < 0x10100000L) || defined(LIBRESSL_VERSION_NUMBER)
         SSL_library_init();
         SSL_load_error_strings();
@@ -504,10 +575,13 @@ void Ssl_start() {
                 RAND_load_file(RANDOM_DEVICE, RANDOM_BYTES);
         else
                 THROW(AssertException, "SSL: cannot find %s nor %s on the system", URANDOM_DEVICE, RANDOM_DEVICE);
+#ifdef HAVE_SSL_CTX_SET_KEYLOG_CALLBACK
+        keylogName = getenv("SSLKEYLOGFILE");
+#endif
 }
 
 
-void Ssl_stop() {
+void Ssl_stop(void) {
 #if (OPENSSL_VERSION_NUMBER < 0x10100000L) || defined(LIBRESSL_VERSION_NUMBER)
         CRYPTO_THREADID_set_callback(NULL);
         CRYPTO_set_locking_callback(NULL);
@@ -521,7 +595,7 @@ void Ssl_stop() {
 }
 
 
-void Ssl_threadCleanup() {
+void Ssl_threadCleanup(void) {
 #if (OPENSSL_VERSION_NUMBER < 0x10100000L) || defined(LIBRESSL_VERSION_NUMBER)
         ERR_remove_thread_state(NULL);
 #endif
@@ -539,7 +613,7 @@ void Ssl_setFipsMode(bool enabled) {
 
 
 T Ssl_new(SslOptions_T options) {
-        ASSERT(options);
+        assert(options);
         T C;
         NEW(C);
         C->options = options;
@@ -556,6 +630,9 @@ T Ssl_new(SslOptions_T options) {
                 Log_error("SSL: client context initialization failed -- %s\n", SSLERROR);
                 goto sslerror;
         }
+#ifdef HAVE_SSL_CTX_SET_KEYLOG_CALLBACK
+        _keylogSet(C->ctx);
+#endif
         if (! _setVersion(C->ctx, options)) {
                 goto sslerror;
         }
@@ -594,7 +671,7 @@ sslerror:
 
 
 void Ssl_free(T *C) {
-        ASSERT(C && *C);
+        assert(C && *C);
         if ((*C)->handler)
                 SSL_free((*C)->handler);
         if ((*C)->ctx && ! (*C)->accepted)
@@ -604,10 +681,11 @@ void Ssl_free(T *C) {
 
 
 void Ssl_close(T C) {
-        ASSERT(C);
+        assert(C);
         bool retry = false;
         int timeout = Run.limits.networkTimeout;
         do {
+                ERR_clear_error();
                 int rv = SSL_shutdown(C->handler);
                 if (rv == 0) {
                         // close notify sent
@@ -636,14 +714,15 @@ void Ssl_close(T C) {
 
 
 void Ssl_connect(T C, int socket, int timeout, const char *name) {
-        ASSERT(C);
-        ASSERT(socket >= 0);
+        assert(C);
+        assert(socket >= 0);
         C->socket = socket;
         SSL_set_connect_state(C->handler);
         SSL_set_fd(C->handler, C->socket);
         _setServerNameIdentification(C, name);
         bool retry = false;
         do {
+                ERR_clear_error();
                 int rv = SSL_connect(C->handler);
                 if (rv < 0) {
                         switch (SSL_get_error(C->handler, rv)) {
@@ -671,11 +750,12 @@ void Ssl_connect(T C, int socket, int timeout, const char *name) {
 
 
 int Ssl_write(T C, const void *b, int size, int timeout) {
-        ASSERT(C);
+        assert(C);
         int n = 0;
         if (size > 0) {
                 bool retry = false;
                 do {
+                        ERR_clear_error();
                         switch (SSL_get_error(C->handler, (n = SSL_write(C->handler, b, size)))) {
                                 case SSL_ERROR_NONE:
                                 case SSL_ERROR_ZERO_RETURN:
@@ -712,11 +792,12 @@ int Ssl_write(T C, const void *b, int size, int timeout) {
 
 
 int Ssl_read(T C, void *b, int size, int timeout) {
-        ASSERT(C);
+        assert(C);
         int n = 0;
         if (size > 0) {
                 bool retry = false;
                 do {
+                        ERR_clear_error();
                         switch (SSL_get_error(C->handler, (n = SSL_read(C->handler, b, size)))) {
                                 case SSL_ERROR_NONE:
                                 case SSL_ERROR_ZERO_RETURN:
@@ -796,8 +877,8 @@ int Ssl_getCertificateValidDays(T C) {
 
 
 char *Ssl_printOptions(SslOptions_T options, char *b, int size) {
-        ASSERT(b);
-        ASSERT(size > 0);
+        assert(b);
+        assert(size > 0);
         *b = 0;
         if (options->flags) {
                 int count = 0;
@@ -845,8 +926,8 @@ char *Ssl_printOptions(SslOptions_T options, char *b, int size) {
 
 
 SslServer_T SslServer_new(int socket, SslOptions_T options) {
-        ASSERT(socket >= 0);
-        ASSERT(options);
+        assert(socket >= 0);
+        assert(options);
         SslServer_T S;
         NEW(S);
         S->socket = socket;
@@ -883,6 +964,9 @@ SslServer_T SslServer_new(int socket, SslOptions_T options) {
 #ifdef SSL_OP_NO_SESSION_RESUMPTION_ON_RENEGOTIATION
         SSL_CTX_set_options(S->ctx, SSL_OP_NO_SESSION_RESUMPTION_ON_RENEGOTIATION);
 #endif
+#ifdef SSL_OP_NO_RENEGOTIATION
+        SSL_CTX_set_options(S->ctx, SSL_OP_NO_RENEGOTIATION);
+#endif
 #ifdef SSL_CTRL_SET_ECDH_AUTO
         SSL_CTX_set_options(S->ctx, SSL_OP_SINGLE_ECDH_USE);
         SSL_CTX_set_ecdh_auto(S->ctx, 1);
@@ -946,7 +1030,7 @@ sslerror:
 
 
 void SslServer_free(SslServer_T *S) {
-        ASSERT(S && *S);
+        assert(S && *S);
         if ((*S)->ctx)
                 SSL_CTX_free((*S)->ctx);
         FREE(*S);
@@ -954,7 +1038,7 @@ void SslServer_free(SslServer_T *S) {
 
 
 T SslServer_newConnection(SslServer_T S) {
-        ASSERT(S);
+        assert(S);
         T C;
         NEW(C);
         C->accepted = true;
@@ -970,22 +1054,22 @@ T SslServer_newConnection(SslServer_T S) {
 }
 
 
-void SslServer_freeConnection(SslServer_T S, T *C) {
-        ASSERT(S);
-        ASSERT(C && *C);
+void SslServer_freeConnection(T *C) {
+        assert(C && *C);
         Ssl_close(*C);
         Ssl_free(C);
 }
 
 
 bool SslServer_accept(T C, int socket, int timeout) {
-        ASSERT(C);
-        ASSERT(socket >= 0);
+        assert(C);
+        assert(socket >= 0);
         C->socket = socket;
         SSL_set_accept_state(C->handler);
         SSL_set_fd(C->handler, C->socket);
         bool retry = false;
         do {
+                ERR_clear_error();
                 int rv = SSL_accept(C->handler);
                 if (rv < 0) {
                         switch (SSL_get_error(C->handler, rv)) {
