@@ -53,7 +53,7 @@ char *Util_replaceString(char **src, const char *old, const char *new);
  * @param s The String to search for word in
  * @param word The sub-string to count in s
  */
-int Util_countWords(char *s, const char *word);
+size_t Util_countWords(const char *s, const char *word);
 
 
 /**
@@ -134,7 +134,7 @@ char *Util_monitId(char *idfile);
 /**
  * Open and read the pid from the given pidfile.
  * @param pidfile A pidfile with full path
- * @return the pid or 0 if the pid could
+ * @return the pid or -1 if the pid could
  * not be read from the file
  */
 pid_t Util_getPid(char *pidfile);
